/*
** FILE NAME:     lcd_st7565.h
**
** PROJECT:       Meta/DSP Software Library
**
** TITLE:         Graphic LCD ST7565 driver
**
** AUTHOR:        R&D center HW team
**
** DESCRIPTION:   Common API functions.
**
**
** MODIFICATION
** HISTORY:
**                Version 1.0 18/11/4
**                  - initial revision
*/


/*
**	API function return values
*/
#define LCD_OK				(0)		//function completed normally
#define LCD_ERR				(1)		//error: undefined
#define LCD_ERR_CODE		(2)		//error: invalid special character code

#define NUM_COL 	(128)
#define NUM_PAGE 	(8)
#define VERT_PIXEL 	(8)
#define NUM_ROW 	(NUM_PAGE*VERT_PIXEL)

#define SIGN(n) ((n) < 0) ? -1 : ((n) > 0) ? 1 : 0
#define ON_SCR(p) ((p).x >= 0) && ((p).x < NUM_COL) && ((p).y >= 0) && ((p).y < NUM_ROW)
#define BITMASK(b) (1 << (b))


#define SCR_CLEAR_BYTE 0x00

#define GLCD_DISP_ON 				(0xAF)
#define GLCD_DISP_OFF 				(0xAE)
#define GLCD_START_LINE_SET 		(0x40)
#define GLCD_PAGE_ADDR_SET  		(0xB0)
#define GLCD_COL_ADDR_UPPER 		(0x10)
#define GLCD_COL_ADDR_LOWER 		(0x00)
#define GLCD_STATUS_READ_MASK		(0xF0)
#define GLCD_DISP_NORMAL  			(0xA6)
#define GLCD_DISP_REVERSE 			(0xA7)
#define GLCD_ADC_SELECT_REVERSE 	(0xA1)
#define GLCD_ADC_SELECT_NORMAL  	(0xA0)
#define GLCD_DISP_ALL_POINT_ON 		(0xA4)
#define GLCD_DISP_ALL_POINT_OFF 	(0xA5)
#define GLCD_BIAS_SET 				(0xA2) //sets the LCD drive voltage bias ratio 1/9(0xA2) or 1/7(0xA3)
#define GLCD_COL_ADDR_INCREMENT 	(0xE0)
#define GLCD_COL_ADDR_INC_END 		(0xEE)
#define GLCD_INTERNAL_RESET 		(0xE2)
#define GLCD_COMMON_OUTPUT_NOR  	(0xC0)
#define GLCD_COMMON_OUTPUT_REV  	(0xC8)
#define GLCD_POWER_CTR_SET_MASK		(0x28)
#define GLCD_INTER_RESI_RATIO_SET	(0x20)
#define GLCD_ELECT_VOL_MODE_SET		(0x81)
#define GLCD_STATIC_INDI_ON  		(0xAC)
#define GLCD_STATIC_INDI_OFF  		(0xAD)
#define GLCD_COM_WR_STATE			(0)
#define GLCD_DAT_WR_STATE			(1)

#define high	(1)
#define low		(0)
#define BOT		(1)
#define TOP		(0)


void LCDGraphicInit(void);
unsigned char scrDrawChar(const char *str, unsigned char order, unsigned char topbot);
unsigned long scrDrawString(unsigned char topbot, unsigned char *str);
unsigned char glcd_com_dat_write(unsigned char dataBits);
unsigned char glcd_wr_bit_set(unsigned char hilo);
unsigned char glcd_cd_bit_set(unsigned char crtdat);
unsigned long ClearChar(unsigned char topbot, unsigned char index);
void LCD_PowerOff(void);
